@@ -362,6 +362,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateUserSAMLConfig(self, request):
+        """创建用户SAML配置
+
+        :param request: Request instance for CreateUserSAMLConfig.
+        :type request: :class:`tencentcloud.cam.v20190116.models.CreateUserSAMLConfigRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.CreateUserSAMLConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateUserSAMLConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateUserSAMLConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteGroup(self, request):
         """删除用户组
 
@@ -698,6 +726,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSafeAuthFlagIntl(self, request):
+        """查询安全设置(国际站)
+
+        :param request: Request instance for DescribeSafeAuthFlagIntl.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DescribeSafeAuthFlagIntlRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DescribeSafeAuthFlagIntlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeSafeAuthFlagIntl", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSafeAuthFlagIntlResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeSubAccounts(self, request):
         """通过子用户UIN列表查询子用户
 
@@ -726,6 +782,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeUserSAMLConfig(self, request):
+        """查询用户SAML配置
+
+        :param request: Request instance for DescribeUserSAMLConfig.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DescribeUserSAMLConfigRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DescribeUserSAMLConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeUserSAMLConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeUserSAMLConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DetachGroupPolicy(self, request):
         """本接口（DetachGroupPolicy）可用于解除绑定到用户组的策略。
 
@@ -810,6 +894,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetAccountSummary(self, request):
+        """查询账户摘要
+
+        :param request: Request instance for GetAccountSummary.
+        :type request: :class:`tencentcloud.cam.v20190116.models.GetAccountSummaryRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.GetAccountSummaryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetAccountSummary", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetAccountSummaryResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetCustomMFATokenInfo(self, request):
         """获取自定义多因子Token关联信息
 
@@ -1812,6 +1924,34 @@ class CamClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UpdateUserSAMLConfig(self, request):
+        """修改用户SAML配置
+
+        :param request: Request instance for UpdateUserSAMLConfig.
+        :type request: :class:`tencentcloud.cam.v20190116.models.UpdateUserSAMLConfigRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.UpdateUserSAMLConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateUserSAMLConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateUserSAMLConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
